/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package org.apache.hugegraph.loader.source;

import org.apache.hugegraph.loader.constant.Checkable;
import org.apache.hugegraph.loader.source.file.FileSource;

import com.fasterxml.jackson.annotation.JsonProperty;

public interface InputSource extends Checkable {

    @JsonProperty("type")
    SourceType type();

    String[] header();

    String charset();

    FileSource asFileSource();

    // Whether input source is case-sensitive
    // Case-sensitive by default, only false when input is parquet, orc format
    default boolean headerCaseSensitive() {
        return true;
    }
}
